@@ -1,6 +1,6 @@
 import re
 from dataclasses import asdict, dataclass
-from typing import Any, Dict, List, Tuple, Union
+from typing import Any, Dict, List, Union
 
 from py_pdf_term._common.consts import NOSPACE_REGEX
 from py_pdf_term.tokenizer import Token
@@ -8,9 +8,6 @@ from py_pdf_term.tokenizer import Token
 GARBAGE_SPACE = re.compile(rf"(?<={NOSPACE_REGEX}) (?=\S)|(?<=\S) (?={NOSPACE_REGEX})")
 
 
-LinguSeq = Tuple[Tuple[str, str, str], ...]
-
-
 @dataclass(frozen=True)
 class Term:
     tokens: List[Token]
@@ -42,11 +39,6 @@ class Term:
             "", " ".join(map(lambda token: token.lemma, self.tokens))
         )
 
-    def linguistic_sequence(self) -> LinguSeq:
-        return tuple(
-            (token.pos, token.category, token.subcategory) for token in self.tokens
-        )
-
     def to_dict(self) -> Dict[str, Any]:
         return {
             "tokens": list(map(lambda token: token.to_dict(), self.tokens)),
