@@ -1,7 +1,5 @@
-from .japanese import JapaneseConcatenationFilter
 from .english import EnglishConcatenationFilter
+from .japanese import JapaneseConcatenationFilter
 
-__all__ = [
-    "JapaneseConcatenationFilter",
-    "EnglishConcatenationFilter",
-]
+# isort: unique-list
+__all__ = ["EnglishConcatenationFilter", "JapaneseConcatenationFilter"]
