@@ -1,7 +1,5 @@
-from .japanese import JapaneseNumericFilter
 from .english import EnglishNumericFilter
+from .japanese import JapaneseNumericFilter
 
-__all__ = [
-    "JapaneseNumericFilter",
-    "EnglishNumericFilter",
-]
+# isort: unique-list
+__all__ = ["EnglishNumericFilter", "JapaneseNumericFilter"]
