@@ -1,9 +1,7 @@
-from .extractor import PyPDFTermExtractor
-from .data import DomainPDFList
 from py_pdf_term.techterms import PDFTechnicalTermList
 
-__all__ = [
-    "PyPDFTermExtractor",
-    "DomainPDFList",
-    "PDFTechnicalTermList",
-]
+from .data import DomainPDFList
+from .extractor import PyPDFTermExtractor
+
+# isort: unique-list
+__all__ = ["DomainPDFList", "PDFTechnicalTermList", "PyPDFTermExtractor"]
