@@ -1,41 +1,35 @@
-from .pdftoxml import (
-    BinaryOpenerMapper,
+from .caches import (
+    CandidateLayerCacheMapper,
+    MethodLayerDataCacheMapper,
+    MethodLayerRankingCacheMapper,
+    StylingLayerCacheMapper,
+    XMLLayerCacheMapper,
 )
 from .candidates import (
-    LanguageTokenizerMapper,
-    CandidateMorphemeFilterMapper,
-    CandidateTermFilterMapper,
-    SplitterMapper,
     AugmenterMapper,
+    CandidateTermFilterMapper,
+    CandidateTokenFilterMapper,
+    LanguageTokenizerMapper,
+    SplitterMapper,
 )
-from .methods import (
-    SingleDomainRankingMethodMapper,
-    MultiDomainRankingMethodMapper,
-)
-from .stylings import (
-    StylingScoreMapper,
-)
-from .caches import (
-    XMLLayerCacheMapper,
-    CandidateLayerCacheMapper,
-    MethodLayerRankingCacheMapper,
-    MethodLayerDataCacheMapper,
-    StylingLayerCacheMapper,
-)
+from .methods import MultiDomainRankingMethodMapper, SingleDomainRankingMethodMapper
+from .pdftoxml import BinaryOpenerMapper
+from .stylings import StylingScoreMapper
 
+# isort: unique-list
 __all__ = [
-    "BinaryOpenerMapper",
-    "LanguageTokenizerMapper",
-    "CandidateMorphemeFilterMapper",
-    "CandidateTermFilterMapper",
-    "SplitterMapper",
     "AugmenterMapper",
-    "SingleDomainRankingMethodMapper",
+    "BinaryOpenerMapper",
+    "CandidateLayerCacheMapper",
+    "CandidateTermFilterMapper",
+    "CandidateTokenFilterMapper",
+    "LanguageTokenizerMapper",
+    "MethodLayerDataCacheMapper",
+    "MethodLayerRankingCacheMapper",
     "MultiDomainRankingMethodMapper",
+    "SingleDomainRankingMethodMapper",
+    "SplitterMapper",
+    "StylingLayerCacheMapper",
     "StylingScoreMapper",
     "XMLLayerCacheMapper",
-    "CandidateLayerCacheMapper",
-    "MethodLayerRankingCacheMapper",
-    "MethodLayerDataCacheMapper",
-    "StylingLayerCacheMapper",
 ]
