@@ -3,7 +3,6 @@ from .data import MethodTermRanking
 from .flr import FLRMethod
 from .flrh import FLRHMethod
 from .hits import HITSMethod
-from .lfidf import LFIDFMethod
 from .mcvalue import MCValueMethod
 from .mdp import MDPMethod
 from .tfidf import TFIDFMethod
@@ -15,7 +14,6 @@ __all__ = [
     "FLRHMethod",
     "FLRMethod",
     "HITSMethod",
-    "LFIDFMethod",
     "MCValueMethod",
     "MDPMethod",
     "MethodTermRanking",
