@@ -2,7 +2,6 @@ from .base import BaseRankingDataCollector
 from .flr import FLRRankingDataCollector
 from .flrh import FLRHRankingDataCollector
 from .hits import HITSRankingDataCollector
-from .lfidf import LFIDFRankingDataCollector
 from .mcvalue import MCValueRankingDataCollector
 from .mdp import MDPRankingDataCollector
 from .tfidf import TFIDFRankingDataCollector
@@ -13,7 +12,6 @@ __all__ = [
     "FLRHRankingDataCollector",
     "FLRRankingDataCollector",
     "HITSRankingDataCollector",
-    "LFIDFRankingDataCollector",
     "MCValueRankingDataCollector",
     "MDPRankingDataCollector",
     "TFIDFRankingDataCollector",
