@@ -1,17 +1,13 @@
-from typing import Dict, Any, Literal
+from typing import Any, Dict
 
 from .base import BaseMultiDomainRankingMethod
-from .rankingdata import TFIDFRankingData
 from .collectors import TFIDFRankingDataCollector
 from .rankers import TFIDFRanker
+from .rankingdata import TFIDFRankingData
 
 
 class TFIDFMethod(BaseMultiDomainRankingMethod[TFIDFRankingData]):
-    def __init__(
-        self,
-        tfmode: Literal["natural", "log", "augmented", "logave", "binary"] = "log",
-        idfmode: Literal["natural", "smooth", "prob", "unary"] = "natural",
-    ) -> None:
+    def __init__(self, tfmode: str = "log", idfmode: str = "natural") -> None:
         collector = TFIDFRankingDataCollector()
         ranker = TFIDFRanker(tfmode=tfmode, idfmode=idfmode)
         super().__init__(collector, ranker)
